declare type DefaultLoadScriptOption = Pick<ILoadScriptOption & ILoadCssOption, 'executionStrategy' | 'timeoutSeconds' | 'appendTo'>;

/**
 * @public
 */
declare const gloader: IGloader;
export default gloader;
export { gloader }

/**
 * @public
 */
export declare interface IGloader {
    loadScript: (op: ILoadScriptOption) => Promise<HTMLScriptElement>;
    loadCss: (op: ILoadCssOption) => Promise<HTMLLinkElement>;
    setDefaultOption: typeof setDefaultOption;
}

/**
 * @public
 */
export declare interface ILoadCssOption extends Option_2 {
    href: string;
}

/**
 * @public
 */
export declare interface ILoadScriptOption extends Option_2 {
    src: string;
    executionStrategy?: 'async' | 'defer';
}

/**
 * @public
 * @param href
 * @param timeoutSeconds
 * @param id
 * @param appendTo
 */
export declare const loadCss: ({ href, timeoutSeconds, id, appendTo }: ILoadCssOption) => Promise<HTMLLinkElement>;

/**
 * @public
 * @param src
 * @param id
 * @param timeoutSeconds
 * @param appendTo
 * @param executionStrategy
 */
export declare const loadScript: ({ src, id, timeoutSeconds, appendTo, executionStrategy, }: ILoadScriptOption) => Promise<HTMLScriptElement>;

/**
 * @public
 */
declare interface Option_2 {
    timeoutSeconds?: number;
    appendTo?: HTMLElement;
    id?: string;
    beforeElementCreateCallback?: (el: HTMLElement) => void;
}

/**
 * @public
 * @param value
 */
export declare const setDefaultOption: (value: DefaultLoadScriptOption) => DefaultLoadScriptOption;

export { }
